==> xd3d-8.2.3.tar.gz: xd3d-8.2.3/src/d3d/com_options.f <==
      PARAMETER (NBPGM=200, NGMAX=1000)
      PARAMETER (NBECH=20, NBANG=16, NTABMAX=38)
      COMMON / OPTIONS / IANG(NBANG),ISDVU(NGMAX)
     &                  ,IANGLE,IFC,IFC0,ICARRE,ISHRINK,IDEMI,IFRONT
     &                  ,I2D,ILEG,NBCOL,ISO,IFISO,IFVISO,IFVIT,IEPISO
     &                  ,ICENTRISO,ICT,IPOST,IPOSTCOL,IEXAG,ISYM,ISYMR
     &                  ,ICTFAC,ICTFAC00,ICTFON,ICTLEG,ICTFLE
     &                  ,ISENS,IFAC,IFAC2,ICOURB,IAXES,IAXESDEF,IBORD
     &                  ,INUMER,IGROUP,IPREFC,IMAILL,IVIT,IPBM,IPGM
     &                  ,ITYPFL,ISLEG,IDIRL,IDIRL0,IPERSP,IPERSP0,INOPO
     &                  ,IECBOI,IBOITE,IFLAG3,MATMIN,MATMAX,IPS2D,ICENTR
     &                  ,IELIMI,IVOL,ICSUR,ITABLE,ITABLE0,ISHPRO,IFBLO
     &                  ,ICADPS,ISAUVEGRAPH,IDEFPS,IINFO,ITITAV,IDSEUL
     &                  ,NPSUR,NSSUR,IEPSEG,ICPTS,ITPTS,ICSEG,IDX0,IDY0
     &                  ,IDX,IDY,IVALMAR,IWILD,IOPREF,ILOGX,ILOGY,ILOGZ
     &                  ,IDEFOR,ICALSU,ICOUPSU,ISOCOUP,IELISO,IFOUTLINE
     &                  ,NODEPL,IFONT0,IFONT1,IFONT2,IFONT3,IFONT4
     &                  ,IFONT5,IFONT7,IFONT8,IOPMAR,IARCH,ITERMC
     &                  ,IROUGE0,IVERT0,IBLEU0,IROUGE1,IVERT1,IBLEU1
     &                  ,ITABLE1,ITABLE2,IMULSAUV,IOPTFORME,IDEBRAP
     &                  ,NECHX,NECHY,NECHZ,ITEMPS,IEPBOR,IEPBOR0,IEPBOR2
     &                  ,IFREEZE,ISOBID,ISOFRO,IVFIXE,IPCOUP
     &                  ,IPROGRE,ICOLAR,ICOLAX,ICOLAXB,ISHIFTX,ISHIFTY
     &                  ,IBATCH,ITOUCHEX,ITOUCHNB,ITOUCHTAB,ILANG,ILANG0
     &                  ,ISTDOUT,IBORDTHERMO,ICOULTHERMO,ICHARG,ICOURXYZ
     &                  ,NBOGO,NOUTLINEM,IAUTORELOAD,ILEGMAN,ILEGAUTO
     &                  ,IECHFX,IECHFY,IECHFZ,IFIX,IFIXFIX
      COMMON / ROPT    / VAL(256),VALFRO(256),YCOUL(256)
     &                  ,PROPX(NBECH),PROPY(NBECH),PROPZ(NBECH)
     &                  ,XBOITE(8),YBOITE(8),XPUP(3),XCADRE(4),YCADRE(4)
     &                  ,VMIN,VMAX,VMINISO,VMAXISO
     &                  ,VMIN0,VMAX0,VITMIN,VITMAX
     &                  ,BX,BY,BZ,BX0,BY0,BZ0,BX00,BY00,BZ00,BNOR
     &                  ,XMINS,XMAXS,YMINS,YMAXS
     &                  ,XMINR,XMAXR,YMINR,YMAXR,BXSYM,BYSYM
     &                  ,BMIDX,BMIDY,BMIDZ,HXA4,HYA4,HYA4A,HYA4B
     &                  ,FACEXA,FACEXAX,FACEXAY,FACEXAZ
     &                  ,EXAX0,EXAY0,EXAZ0,EXAX00,EXAY00,EXAZ00
     &                  ,FACDIO,FACVIT,FACVIT0,FACLEG,DIST,DIST0
     &                  ,XMIL,YMIL,XSHIFT,YSHIFT,DIAMIN,TOL
     &                  ,DIMMAXX,DIMMAXY,DIMMAXZ,DIMMAX
     &                  ,DIMMAXXREF,DIMMAXYREF,DIMMAXZREF,DIMMAXREF
     &                  ,DEPXM,DEPYM,DEPZM,DEPMAX,ANGPS,VSHPRO,FACPTS
     &                  ,XMIREE,XMAREE,YMIREE,YMAREE,EPSISO
     &                  ,XXMIN,XXMAX,YYMIN,YYMAX,XCUR,YCUR,XLARG
     &                  ,XCUREF,YCUREF,XLAREF
     &                  ,XDMIN,XDMIN0,XHELP,XDMAX,XDMA2
     &                  ,YDMIN,YDMAX,YDMI2,YDMI20,CMINI,CMAXI,USDC
     &                  ,XPTHER,YPTHER,DXTHER,DYTHER,XINFO,YINFO,BSOMB
     &                  ,XBIDONCOM,YBIDONCOM,XCOUL,XLIMTAB,RBOUL,PIXEL
     &                  ,XFMIN,XFMAX,YFMIN,YFMAX,ZMIN,ZMAX
     &                  ,XBMIN,XBMAX,YBMIN,YBMAX,ZBMIN,ZBMAX
     &                  ,XINIT_ECH(2,3)
     &                  ,VMINXYZ(3),VMAXXYZ(3),VCOUPXYZ(3)
     &                  ,XORIG,YORIG,ZORIG
      LOGICAL*4 SIG,VITCOUL,CLIGNE
      COMMON / LOGOPT  / SIG,VITCOUL,CLIGNE
      REAL*8    XECH(NBECH),YECH(NBECH),ZECH(NBECH)
     &         ,BIG,USBIG
      COMMON / ECHECH / XECH,YECH,ZECH,BIG,USBIG,BIGS
      CHARACTER*512 TITRE
      CHARACTER*132 LEG,SAUVPS
      CHARACTER*128 NOM_FICH,NOMF0,NOM_ISO,NOM_VIT,NOM_C1,NOM_C2
     &             ,NOM_COUR
      CHARACTER*80  PROG,PROGEFF,TITAV,CHEMDOC,NOMPS
      CHARACTER*20  ELEMENTS
      CHARACTER*14  HELPPS
      CHARACTER*6   CCOU
      CHARACTER*2   CCOR
      COMMON / CARA    / LEG,SAUVPS,NOM_FICH,NOMF0,NOM_ISO
     &                  ,NOM_VIT,NOM_C1,NOM_C2,NOM_COUR
     &                  ,PROG,PROGEFF,TITAV
     &                  ,CHEMDOC,NOMPS,ELEMENTS,HELPPS
      COMMON / CARALON / LONLEG,LSPS,LONG,LONG0,LONG2,LONISO
     &                  ,LONVIT,LONC1,LONC2,LONCOUR
     &                  ,LPROG,LPROGEFF,LONTIT
     &                  ,LENCHEM,LONPS,LELEM
      COMMON / DATEFIC / IDFICH,IDDEPL,IDISO,IDVIT
      COMMON / VALDES  / VALG(NBPGM),XXXG(NBPGM),YYYG(NBPGM),NBPG
      COMMON /CARAPOUB1 / TITRE
      COMMON /CARAPOUB3 / CCOU
      COMMON /CARAPOUB4 / CCOR
C
      CHARACTER DATE*6,MOI*8,MEMO*20
      COMMON /DIVERSINFO/ MOI,MEMO,DATE
      INTEGER ICC(0:16),ICA(0:14),ICF(0:14),ICREF(0:15),ICBLO(7,2)
      COMMON /DIVERSCOUL/ ICC,ICA,ICF,ICREF,ICBLO

==> xd3d-8.3.1.tar.gz: xd3d-8.3.1/src/d3d/com_options.f <==
      PARAMETER (NBPGM=200, NGMAX=1000)
      PARAMETER (NBECH=20, NBANG=16, NTABMAX=38)
      COMMON / OPTIONS / IANG(NBANG),ISDVU(NGMAX)
     &                  ,IANGLE,IFC,IFC0,ICARRE,ISHRINK,IDEMI,IFRONT
     &                  ,I2D,ILEG,NBCOL,ISO,IFISO,IFVISO,IFVIT,IEPISO
     &                  ,ICENTRISO,ICT,IPOST,IPOSTCOL,IEXAG,ISYM,ISYMR
     &                  ,ICTFAC,ICTFAC00,ICTFON,ICTLEG,ICTFLE
     &                  ,ISENS,IFAC,IFAC2,ICOURB,IAXES,IAXESDEF,IBORD
     &                  ,INUMER,IGROUP,IPREFC,IORIENT,IMAILL,IVIT
     &                  ,IPBM,IPGM
     &                  ,ITYPFL,ISLEG,IDIRL,IDIRL0,IPERSP,IPERSP0,INOPO
     &                  ,IECBOI,IBOITE,IFLAG3,MATMIN,MATMAX,IPS2D,ICENTR
     &                  ,IELIMI,IVOL,ICSUR,ITABLE,ITABLE0,ISHPRO,IFBLO
     &                  ,ICADPS,ISAUVEGRAPH,IDEFPS,IINFO,ITITAV,IDSEUL
     &                  ,NPSUR,NSSUR,IEPSEG,ICPTS,ITPTS,ICSEG,IDX0,IDY0
     &                  ,IDX,IDY,IVALMAR,IWILD,IOPREF,ILOGX,ILOGY,ILOGZ
     &                  ,IDEFOR,ICALSU,ICOUPSU,ISOCOUP,IELISO,IFOUTLINE
     &                  ,NODEPL,IFONT0,IFONT1,IFONT2,IFONT3,IFONT4
     &                  ,IFONT5,IFONT7,IFONT8,IOPMAR,IARCH,ITERMC
     &                  ,IROUGE0,IVERT0,IBLEU0,IROUGE1,IVERT1,IBLEU1
     &                  ,ITABLE1,ITABLE2,IMULSAUV,IOPTFORME,IDEBRAP
     &                  ,NECHX,NECHY,NECHZ,ITEMPS,IEPBOR,IEPBOR0,IEPBOR2
     &                  ,IFREEZE,ISOBID,ISOFRO,IVFIXE,IPCOUP
     &                  ,IPROGRE,ICOLAR,ICOLAX,ICOLAXB,ISHIFTX,ISHIFTY
     &                  ,IBATCH,ITOUCHEX,ITOUCHNB,ITOUCHTAB,ILANG,ILANG0
     &                  ,ISTDOUT,IBORDTHERMO,ICOULTHERMO,ICHARG,ICOURXYZ
     &                  ,NBOGO,NOUTLINEM,IAUTORELOAD,ILEGMAN,ILEGAUTO
     &                  ,IECHFX,IECHFY,IECHFZ,IFIX,IFIXFIX,ISAUVEMESH
     &                  ,IDEPOUILLE
      COMMON / ROPT    / VAL(256),VALFRO(256),YCOUL(256)
     &                  ,PROPX(NBECH),PROPY(NBECH),PROPZ(NBECH)
     &                  ,XBOITE(8),YBOITE(8),XPUP(3),XCADRE(4),YCADRE(4)
     &                  ,VMIN,VMAX,VMINISO,VMAXISO
     &                  ,VMIN0,VMAX0,VITMIN,VITMAX
     &                  ,BX,BY,BZ,BX0,BY0,BZ0,BX00,BY00,BZ00,BNOR
     &                  ,XMINS,XMAXS,YMINS,YMAXS
     &                  ,XMINR,XMAXR,YMINR,YMAXR,BXSYM,BYSYM
     &                  ,BMIDX,BMIDY,BMIDZ,HXA4,HYA4,HYA4A,HYA4B
     &                  ,FACEXA,FACEXAX,FACEXAY,FACEXAZ
     &                  ,EXAX0,EXAY0,EXAZ0,EXAX00,EXAY00,EXAZ00
     &                  ,FACDIO,FACVIT,FACVIT0,FACLEG,DIST,DIST0
     &                  ,XMIL,YMIL,XSHIFT,YSHIFT,DIAMIN,TOL
     &                  ,DIMMAXX,DIMMAXY,DIMMAXZ,DIMMAX
     &                  ,DIMMAXXREF,DIMMAXYREF,DIMMAXZREF,DIMMAXREF
     &                  ,DEPXM,DEPYM,DEPZM,DEPMAX,ANGPS,VSHPRO,FACPTS
     &                  ,XMIREE,XMAREE,YMIREE,YMAREE,EPSISO
     &                  ,XXMIN,XXMAX,YYMIN,YYMAX,XCUR,YCUR,XLARG
     &                  ,XCUREF,YCUREF,XLAREF
     &                  ,XDMIN,XDMIN0,XHELP,XDMAX,XDMA2
     &                  ,YDMIN,YDMAX,YDMI2,YDMI20,CMINI,CMAXI,USDC
     &                  ,XPTHER,YPTHER,DXTHER,DYTHER,XINFO,YINFO,BSOMB
     &                  ,XBIDONCOM,YBIDONCOM,XCOUL,XLIMTAB,RBOUL,PIXEL
     &                  ,XFMIN,XFMAX,YFMIN,YFMAX,ZMIN,ZMAX
     &                  ,XBMIN,XBMAX,YBMIN,YBMAX,ZBMIN,ZBMAX
     &                  ,XINIT_ECH(2,3)
     &                  ,VMINXYZ(3),VMAXXYZ(3),VCOUPXYZ(3)
     &                  ,XORIG,YORIG,ZORIG
      LOGICAL*4 SIG,VITCOUL,CLIGNE
      COMMON / LOGOPT  / SIG,VITCOUL,CLIGNE
      REAL*8    XECH(NBECH),YECH(NBECH),ZECH(NBECH)
     &         ,BIG,USBIG
      COMMON / ECHECH / XECH,YECH,ZECH,BIG,USBIG,BIGS
      CHARACTER*512 TITRE
      CHARACTER*132 LEG,SAUVPS
      CHARACTER*128 NOM_FICH,NOMF0,NOM_ISO,NOM_VIT,NOM_C1,NOM_C2
     &             ,NOM_COUR
      CHARACTER*80  PROG,PROGEFF,TITAV,CHEMDOC,NOMPS
      CHARACTER*20  ELEMENTS
      CHARACTER*14  HELPPS
      CHARACTER*6   CCOU
      CHARACTER*2   CCOR
      COMMON / CARA    / LEG,SAUVPS,NOM_FICH,NOMF0,NOM_ISO
     &                  ,NOM_VIT,NOM_C1,NOM_C2,NOM_COUR
     &                  ,PROG,PROGEFF,TITAV
     &                  ,CHEMDOC,NOMPS,ELEMENTS,HELPPS
      COMMON / CARALON / LONLEG,LSPS,LONG,LONG0,LONG2,LONISO
     &                  ,LONVIT,LONC1,LONC2,LONCOUR
     &                  ,LPROG,LPROGEFF,LONTIT
     &                  ,LENCHEM,LONPS,LELEM
      COMMON / DATEFIC / IDFICH,IDDEPL,IDISO,IDVIT
      COMMON / VALDES  / VALG(NBPGM),XXXG(NBPGM),YYYG(NBPGM),NBPG
      COMMON /CARAPOUB1 / TITRE
      COMMON /CARAPOUB3 / CCOU
      COMMON /CARAPOUB4 / CCOR
C
      CHARACTER DATE*6,MOI*8,MEMO*20
      COMMON /DIVERSINFO/ MOI,MEMO,DATE
      INTEGER ICC(0:16),ICA(0:14),ICF(0:14),ICREF(0:15),ICBLO(7,2)
      COMMON /DIVERSCOUL/ ICC,ICA,ICF,ICREF,ICBLO
